@@ -80,7 +80,7 @@ class ApiArgumentParser(ArgumentParser):
             }
 
         elif args.config_key:
-            credentials = config.get_settings_at_path(args.config_key)
+            credentials = config.get_settings(args.config_key)
 
         elif args.default_client:
             credentials = config.default_client()
