@@ -17,10 +17,12 @@ class TestConfig(unittest.TestCase):
         cluster = config.get_cluster("dev")
         self.assertIn('client_id', cluster)
 
-        # get_client() should merge the cluster if it is referenced instead of
-        # an explicit client_id and client_secret
+    def test_merging(self):
+        # test merging clusters into clients
         client = config.get_client("cluster-client")
-        self.assertEqual(client['client_id'], cluster['client_id'])
+        self.assertEqual(client['client_id'], 'dev client_id')
+        # client settings should not be overwritten
+        self.assertEqual(client['apid_uri'], 'https://cluster.example.com')
 
     def test_defaults(self):
         # test convenience funcitons for getting defaults
@@ -31,6 +33,11 @@ class TestConfig(unittest.TestCase):
             self.assertIn('client_secret', client)
             self.assertIn('apid_uri', client)
 
+    def test_settings(self):
+        # test looking up clusters or clients without specifying which
+        settings = config.get_settings('dev')
+        self.assertEqual(settings['client_id'], "dev client_id")
+
     def test_resolving_keys(self):
         # test resolving keys using dot-notation
         client = config.get_settings_at_path("some.arbitrary.path")
